Glossary
========


.. glossary::

    Execution Environment
      Execution Environments are container images intended to be used as Ansible control nodes.
      Starting in version 2.0, `ansible-runner <https://ansible-runner.readthedocs.io/en/latest/>`_.
      can make use of these images.


    Control node
      The machine or container running Ansible.
      See the `Ansible documentation <https://docs.ansible.com/ansible/latest/network/getting_started/basic_concepts.html#control-node>`_
      for a more comprehensive explanation.
